==> helm-annotations-4.0.0-sources.jar: io/dekorate/helm/config/ValuesSchemaPropertyFluent.java <==
package io.dekorate.helm.config;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValuesSchemaPropertyFluent<A extends ValuesSchemaPropertyFluent<A>> extends BaseFluent<A>{
  public ValuesSchemaPropertyFluent() {
  }
  public ValuesSchemaPropertyFluent(ValuesSchemaProperty instance) {
    instance = (instance != null ? instance : new ValuesSchemaProperty());

    if (instance != null) {
      this.withName(instance.getName());
      this.withDescription(instance.getDescription());
      this.withType(instance.getType());
      this.withMinimum(instance.getMinimum());
      this.withMaximum(instance.getMaximum());
      this.withPattern(instance.getPattern());
      this.withRequired(instance.getRequired());
    }
  }
  private String name;
  private String description;
  private String type;
  private Integer minimum;
  private Integer maximum;
  private String pattern;
  private Boolean required;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public boolean hasDescription() {
    return this.description != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public boolean hasType() {
    return this.type != null;
  }
  public Integer getMinimum() {
    return this.minimum;
  }
  public A withMinimum(Integer minimum) {
    this.minimum=minimum; return (A) this;
  }
  public boolean hasMinimum() {
    return this.minimum != null;
  }
  public Integer getMaximum() {
    return this.maximum;
  }
  public A withMaximum(Integer maximum) {
    this.maximum=maximum; return (A) this;
  }
  public boolean hasMaximum() {
    return this.maximum != null;
  }
  public String getPattern() {
    return this.pattern;
  }
  public A withPattern(String pattern) {
    this.pattern=pattern; return (A) this;
  }
  public boolean hasPattern() {
    return this.pattern != null;
  }
  public Boolean getRequired() {
    return this.required;
  }
  public A withRequired(Boolean required) {
    this.required=required; return (A) this;
  }
  public boolean hasRequired() {
    return this.required != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValuesSchemaPropertyFluent that = (ValuesSchemaPropertyFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(description, that.description)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(minimum, that.minimum)) return false;

    if (!java.util.Objects.equals(maximum, that.maximum)) return false;

    if (!java.util.Objects.equals(pattern, that.pattern)) return false;

    if (!java.util.Objects.equals(required, that.required)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  description,  type,  minimum,  maximum,  pattern,  required,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (minimum != null) { sb.append("minimum:"); sb.append(minimum + ","); }
    if (maximum != null) { sb.append("maximum:"); sb.append(maximum + ","); }
    if (pattern != null) { sb.append("pattern:"); sb.append(pattern + ","); }
    if (required != null) { sb.append("required:"); sb.append(required); }
    sb.append("}");
    return sb.toString();
  }
  public A withRequired() {
    return withRequired(true);
  }
  
}

==> helm-annotations-4.0.3-sources.jar: io/dekorate/helm/config/ValuesSchemaPropertyFluent.java <==
package io.dekorate.helm.config;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ValuesSchemaPropertyFluent<A extends ValuesSchemaPropertyFluent<A>> extends BaseFluent<A>{
  public ValuesSchemaPropertyFluent() {
  }
  
  public ValuesSchemaPropertyFluent(ValuesSchemaProperty instance) {
    this.copyInstance(instance);
  }
  private String name;
  private String description;
  private String type;
  private Integer minimum;
  private Integer maximum;
  private String pattern;
  private Boolean required;
  
  protected void copyInstance(ValuesSchemaProperty instance) {
    instance = (instance != null ? instance : new ValuesSchemaProperty());
    if (instance != null) {
          this.withName(instance.getName());
          this.withDescription(instance.getDescription());
          this.withType(instance.getType());
          this.withMinimum(instance.getMinimum());
          this.withMaximum(instance.getMaximum());
          this.withPattern(instance.getPattern());
          this.withRequired(instance.getRequired());
        }
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name = name;
    return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getDescription() {
    return this.description;
  }
  
  public A withDescription(String description) {
    this.description = description;
    return (A) this;
  }
  
  public boolean hasDescription() {
    return this.description != null;
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type = type;
    return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public Integer getMinimum() {
    return this.minimum;
  }
  
  public A withMinimum(Integer minimum) {
    this.minimum = minimum;
    return (A) this;
  }
  
  public boolean hasMinimum() {
    return this.minimum != null;
  }
  
  public Integer getMaximum() {
    return this.maximum;
  }
  
  public A withMaximum(Integer maximum) {
    this.maximum = maximum;
    return (A) this;
  }
  
  public boolean hasMaximum() {
    return this.maximum != null;
  }
  
  public String getPattern() {
    return this.pattern;
  }
  
  public A withPattern(String pattern) {
    this.pattern = pattern;
    return (A) this;
  }
  
  public boolean hasPattern() {
    return this.pattern != null;
  }
  
  public Boolean getRequired() {
    return this.required;
  }
  
  public A withRequired(Boolean required) {
    this.required = required;
    return (A) this;
  }
  
  public boolean hasRequired() {
    return this.required != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValuesSchemaPropertyFluent that = (ValuesSchemaPropertyFluent) o;
    if (!java.util.Objects.equals(name, that.name)) return false;
    if (!java.util.Objects.equals(description, that.description)) return false;
    if (!java.util.Objects.equals(type, that.type)) return false;
    if (!java.util.Objects.equals(minimum, that.minimum)) return false;
    if (!java.util.Objects.equals(maximum, that.maximum)) return false;
    if (!java.util.Objects.equals(pattern, that.pattern)) return false;
    if (!java.util.Objects.equals(required, that.required)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(name,  description,  type,  minimum,  maximum,  pattern,  required,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (minimum != null) { sb.append("minimum:"); sb.append(minimum + ","); }
    if (maximum != null) { sb.append("maximum:"); sb.append(maximum + ","); }
    if (pattern != null) { sb.append("pattern:"); sb.append(pattern + ","); }
    if (required != null) { sb.append("required:"); sb.append(required); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withRequired() {
    return withRequired(true);
  }
  

}
